@@ -20,16 +20,16 @@
 #include <tqmap.h>
 
 //KDE includes
-#include <klistview.h>
+#include <tdelistview.h>
 
 class CSwordModuleInfo;
 class CSwordBackend;
 
 namespace BookshelfManager {
 
-class CSwordSetupModuleListView : public KListView {
+class CSwordSetupModuleListView : public TDEListView {
 	Q_OBJECT
-  TQ_OBJECT
+  
 
 public:
 	CSwordSetupModuleListView(TQWidget* parent, bool is_remote, sword::InstallSource* installSource = 0);
