@@ -41,9 +41,9 @@
 #include <tqtextstream.h>
 
 //KDE includes
-#include <kconfig.h>
-#include <klocale.h>
-#include <kfiledialog.h>
+#include <tdeconfig.h>
+#include <tdelocale.h>
+#include <tdefiledialog.h>
 #include <kiconloader.h>
 #include <kstandarddirs.h>
 
@@ -53,12 +53,12 @@ using namespace Printing;
 using std::string;
 
 CItemBase::CItemBase(CMainIndex* mainIndex, const Type type)
-: KListViewItem(mainIndex),
+: TDEListViewItem(mainIndex),
 m_type(type),
 m_sortingEnabled(true) {}
 
 CItemBase::CItemBase(CItemBase* parentItem, const Type type)
-: KListViewItem(parentItem),
+: TDEListViewItem(parentItem),
 m_type(type),
 m_sortingEnabled(true) {}
 
@@ -122,7 +122,7 @@ void CItemBase::sortChildItems( int col, bool asc ) {
 		return;
 	}
 	else {
-		KListViewItem::sortChildItems( col, asc );
+		TDEListViewItem::sortChildItems( col, asc );
 	}
 }
 
@@ -132,7 +132,7 @@ void CItemBase::sort() {
 		return;
 	}
 	else {
-		KListViewItem::sort();
+		TDEListViewItem::sort();
 	}
 }
 
@@ -198,7 +198,7 @@ void CModuleItem::dropped( TQDropEvent* e, TQListViewItem* /*after*/) {
 		CDragDropMgr::ItemList dndItems = CDragDropMgr::decode(e);
 		CDragDropMgr::Item item = dndItems.first();
 		if (CDragDropMgr::dndType(e) == CDragDropMgr::Item::Text) { //open the searchdialog
-			//      qWarning("Text dropped!");
+			//      tqWarning("Text dropped!");
 			if ( module() ) {
 				ListCSwordModuleInfo modules;
 				modules.append(module());
@@ -324,7 +324,7 @@ const TQString CBookmarkItem::toolTip() {
 
 	Q_ASSERT(k.get());
 	if (fontPair.first) { //use a special font
-		qWarning("using a font, %s", TQString(fontPair.second.family()).latin1());
+		tqWarning("using a font, %s", TQString(fontPair.second.family()).latin1());
 		ret = TQString::fromLatin1("<b>%1 (%2)</b><br/><small>%3</small><hr><font face=\"%4\" size=\"4\">%5</font>")
 			  .arg(key())
 			  .arg(module()->name())
@@ -473,7 +473,7 @@ void CFolderBase::init() {
 
 /** No descriptions */
 void CFolderBase::setOpen( bool open ) {
-	KListViewItem::setOpen(open);
+	TDEListViewItem::setOpen(open);
 	update();
 }
 
@@ -620,7 +620,7 @@ setText(0, !language().isEmpty() ? ( lang->isValid() ? lang->translatedName() :
 }
 
 void CTreeFolder::initTree() {
-	//  qWarning("CTreeMgr::initTree");
+	//  tqWarning("CTreeMgr::initTree");
 	if (type() == Unknown)
 		return;
 
@@ -703,9 +703,9 @@ namespace Bookmarks {
 	/* --------------------------------------------------------------------------*/
 	const TQString OldBookmarkImport::oldBookmarksXML( const TQString& configFileName ) {
 		TQString fileName = (configFileName.isEmpty()) ? "bt-groupmanager" : configFileName;
-		KConfig* config = new KSimpleConfig( fileName );
+		TDEConfig* config = new KSimpleConfig( fileName );
 
-		KConfigGroupSaver groupSaver(config, configFileName.isEmpty() ? "Groupmanager" : "Bookmarks");
+		TDEConfigGroupSaver groupSaver(config, configFileName.isEmpty() ? "Groupmanager" : "Bookmarks");
 
 		TQDomDocument doc("DOC");
 		doc.appendChild( doc.createProcessingInstruction( "xml", "version=\"1.0\" encoding=\"UTF-8\"" ) );
@@ -728,7 +728,7 @@ namespace Bookmarks {
 		while ( (it_groups != groupList.end()) && (it_parents != parentList.end()) ) {
 			TQDomElement parentElement = (*it_parents == -1) ? content : parentMap[*it_parents];
 			if (parentElement.isNull()) {
-				qWarning("EMPTY PARENT FOUND!");
+				tqWarning("EMPTY PARENT FOUND!");
 				parentElement = content;
 			};
 
@@ -761,7 +761,7 @@ namespace Bookmarks {
 			  ) {
 			TQDomElement parentElement = ((*it_parents) == -1) ? content : parentMap[(*it_parents)];
 			if (parentElement.isNull()) {
-				qWarning("EMPTY PARENT FOUND!");
+				tqWarning("EMPTY PARENT FOUND!");
 				parentElement = content;
 			};
 			TQDomElement elem = doc.createElement("Bookmark");
@@ -948,7 +948,7 @@ CBookmarkFolder::~CBookmarkFolder() {}
 void CBookmarkFolder::initTree() {
 	addGroup(OldBookmarkFolder, "*");
 
-	KStandardDirs stdDirs;
+	TDEStandardDirs stdDirs;
 	const TQString path = stdDirs.saveLocation("data", "bibletime/");
 	if (!path.isEmpty()) {
 		loadBookmarks(path + "bookmarks.xml");
@@ -989,7 +989,7 @@ void CBookmarkFolder::importBookmarks() {
 }
 
 bool CBookmarkFolder::acceptDrop(const TQMimeSource * src) const {
-	//   qWarning("bool CBookmarkFolder::acceptDrop(const TQMimeSource * src): return%ii", (CDragDropMgr::canDecode(src) && (CDragDropMgr::dndType(src) == CDragDropMgr::Item::Bookmark)));
+	//   tqWarning("bool CBookmarkFolder::acceptDrop(const TQMimeSource * src): return%ii", (CDragDropMgr::canDecode(src) && (CDragDropMgr::dndType(src) == CDragDropMgr::Item::Bookmark)));
 
 	return CDragDropMgr::canDecode(src)
 		   && (CDragDropMgr::dndType(src) == CDragDropMgr::Item::Bookmark);
@@ -1052,7 +1052,7 @@ const bool CBookmarkFolder::loadBookmarksFromXML( const TQString& xml ) {
 	doc.setContent(xml);
 	TQDomElement document = doc.documentElement();
 	if( document.tagName() != "SwordBookmarks" ) {
-		qWarning("Not a BibleTime Bookmark XML file");
+		tqWarning("Not a BibleTime Bookmark XML file");
 		return false;
 	}
 
